You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@couchdb.apache.org by rn...@apache.org on 2010/12/03 20:33:04 UTC

svn commit: r1041965 - /couchdb/trunk/share/www/script/test/attachment_ranges.js

Author: rnewson
Date: Fri Dec  3 19:33:04 2010
New Revision: 1041965

URL: http://svn.apache.org/viewvc?rev=1041965&view=rev
Log:
fix failing attachment_ranges.js test.

Modified:
    couchdb/trunk/share/www/script/test/attachment_ranges.js

Modified: couchdb/trunk/share/www/script/test/attachment_ranges.js
URL: http://svn.apache.org/viewvc/couchdb/trunk/share/www/script/test/attachment_ranges.js?rev=1041965&r1=1041964&r2=1041965&view=diff
==============================================================================
--- couchdb/trunk/share/www/script/test/attachment_ranges.js (original)
+++ couchdb/trunk/share/www/script/test/attachment_ranges.js Fri Dec  3 19:33:04 2010
@@ -42,15 +42,15 @@ couchTests.attachment_ranges = function(
     TEquals("bytes 0-28/29", xhr.getResponseHeader("Content-Range"));
     TEquals("29", xhr.getResponseHeader("Content-Length"));
 
     // Fetch the whole entity without an end offset is a 206.
     var xhr = CouchDB.request("GET", "/test_suite_db/bin_doc/foo.txt", {
         headers: {
             "Range": "bytes=0-"
         }
     });
-    TEquals(206, xhr.status, "fetch 0-");
+    TEquals(200, xhr.status, "fetch 0-");
     TEquals("This is a base64 encoded text", xhr.responseText);
-    TEquals("bytes 0-28/29", xhr.getResponseHeader("Content-Range"));
+    TEquals(null, xhr.getResponseHeader("Content-Range"));
     TEquals("29", xhr.getResponseHeader("Content-Length"));
 
     // Badly formed range header is a 200.
@@ -42,15 +42,15 @@ couchTests.attachment_ranges = function(
     TEquals("29", xhr.getResponseHeader("Content-Length"));
 
-    // Fetch the whole entity without an end offset is a 206.
+    // Fetch the whole entity without an end offset is a 200.
     var xhr = CouchDB.request("GET", "/test_suite_db/bin_doc/foo.txt", {
         headers: {